==> vlc-0.7.2.tar.bz2: vlc-0.7.2/modules/codec/cmml/xstrcat.h <==
/*****************************************************************************
 * xstrcat.h: strcat with realloc
 *****************************************************************************
 * Copyright (C) 2004 Commonwealth Scientific and Industrial Research
 *                    Organisation (CSIRO) Australia
 * Copyright (C) 2004 VideoLAN
 *
 * $Id: xstrcat.h 7397 2004-04-20 17:27:30Z sam $
 *
 * Authors: Andre Pang <Andre.Pang@csiro.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#ifndef __XSTRCAT_H__
#define __XSTRCAT_H__

/* like strcat, but realloc's enough memory for the new string too */

static inline
char *xstrcat( char *psz_string, char *psz_to_append )
{
    size_t i_new_string_length = strlen( psz_string ) +
        strlen( psz_to_append ) + 1;

    psz_string = (char *) realloc( psz_string, i_new_string_length );
    
    return strcat( psz_string, psz_to_append );
}

#endif /* __XSTRCAT_H__ */

==> vlc-0.8.1.tar.bz2: vlc-0.8.1/modules/codec/cmml/xstrcat.h <==
/*****************************************************************************
 * xstrcat.h: strcat with realloc
 *****************************************************************************
 * Copyright (C) 2004 Commonwealth Scientific and Industrial Research
 *                    Organisation (CSIRO) Australia
 * Copyright (C) 2004 VideoLAN
 *
 * $Id: xstrcat.h 7775 2004-05-26 08:38:23Z andrep $
 *
 * Authors: Andre Pang <Andre.Pang@csiro.au>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#ifndef __XSTRCAT_H__
#define __XSTRCAT_H__

/* like strcat, but realloc's enough memory for the new string too */

static inline
char *xstrcat( char *psz_string, const char *psz_to_append )
{
    size_t i_new_string_length = strlen( psz_string ) +
        strlen( psz_to_append ) + 1;

    psz_string = (char *) realloc( psz_string, i_new_string_length );

    return strcat( psz_string, psz_to_append );
}

#endif /* __XSTRCAT_H__ */
